.. _data_format:

File Format Specifications
==========================

The File Format Specifications provides a technical manual for understanding and writing
different file formats found in ``sktime``.

.. toctree::
    :maxdepth: 1

    file_specifications/ts
